@@ -86,9 +86,7 @@ class VirtualMachineInstance(NamespacedResource):
         else:
             return pods[0]
 
-        raise ResourceNotFoundError(
-            f"VIRT launcher POD not found for {self.kind}:{self.name}"
-        )
+        raise ResourceNotFoundError
 
     @property
     def virt_handler_pod(self):
@@ -123,20 +121,17 @@ class VirtualMachineInstance(NamespacedResource):
             self.wait_for_status(
                 status=self.Status.RUNNING, timeout=timeout, stop_status=stop_status
             )
-        except TimeoutExpiredError as sampler_ex:
+        except TimeoutExpiredError:
             if not logs:
                 raise
             self.logger.error(f"VMI {self.name} status: {self.instance.status.phase}")
-            try:
-                virt_pod = self.virt_launcher_pod
+            virt_pod = self.virt_launcher_pod
+            if virt_pod:
                 self.logger.error(
                     f"Status of virt-launcher pod {virt_pod.name}: {virt_pod.status}"
                 )
                 self.logger.debug(f"{virt_pod.name} *****LOGS*****")
                 self.logger.debug(virt_pod.log(container="compute"))
-            except ResourceNotFoundError as virt_pod_ex:
-                self.logger.error(virt_pod_ex)
-                raise sampler_ex
 
             raise
 
@@ -153,7 +148,8 @@ class VirtualMachineInstance(NamespacedResource):
             TimeoutExpiredError: If resource not exists.
         """
         self.logger.info(
-            f"Wait until {self.kind} {self.name} is {'Paused' if pause else 'Unpuased'}"
+            f"Wait until {self.kind} {self.name} is "
+            f"{'Paused' if pause else 'Unpuased'}"
         )
         self.wait_for_domstate_pause_status(pause=pause, timeout=timeout)
         self.wait_for_vmi_condition_pause_status(pause=pause, timeout=timeout)
@@ -209,8 +205,7 @@ class VirtualMachineInstance(NamespacedResource):
 
     def virsh_cmd(self, action):
         return shlex.split(
-            "virsh"
-            f" {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
+            f"virsh {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
         )
 
     def get_xml(self):
